pub struct AudioClip {
pub name: String,
pub meta: AudioClipMeta,
pub source: Option<String>,
pub offset: u64,
pub size: u64,
pub stream_info: StreamingInfo,
pub data: Vec<u8>,
pub ambisonic: Option<bool>,
}Expand description
AudioClip object representation
This structure contains all the data needed to represent a Unity AudioClip object. It includes both metadata and the actual audio data.
Fields
name: Stringmeta: AudioClipMetasource: Option<String>offset: u64size: u64stream_info: StreamingInfodata: Vec<u8>ambisonic: Option<bool>Implementations
Sourceimpl AudioClip
impl AudioClip
Sourcepub fn new(name: String, format: AudioCompressionFormat) -> Self
pub fn new(name: String, format: AudioCompressionFormat) -> Self
Create a new AudioClip with basic parameters
Sourcepub fn compression_format(&self) -> AudioCompressionFormat
pub fn compression_format(&self) -> AudioCompressionFormat
Get compression format
Sourcepub fn properties(&self) -> AudioProperties
pub fn properties(&self) -> AudioProperties
Get audio properties
Sourcepub fn is_streamed(&self) -> bool
pub fn is_streamed(&self) -> bool
Check if audio uses external streaming