Module loader

Module loader 

Bundle resource loading and management

This module provides functionality for loading and managing resources from Unity AssetBundles.

Structs

BundleLoader
Bundle resource loader
BundleResourceManager
Bundle resource manager
LoaderStatistics
Loader statistics

Functions

load_bundle
Convenience functions for quick bundle loading Load a single bundle from file
load_bundle_from_memory
Load a bundle from memory
load_bundle_with_options
Load a bundle with specific options