pub fn load_bundle<P>(path: P) -> Result<AssetBundle, BinaryError>Expand description
Convenience functions for quick bundle loading Load a single bundle from file
pub fn load_bundle<P>(path: P) -> Result<AssetBundle, BinaryError>Convenience functions for quick bundle loading Load a single bundle from file