pub fn load_unity_file_from_shared_range(
data: SharedBytes,
range: Range<usize>,
) -> Result<UnityFile, BinaryError>Expand description
Parse a Unity binary file from a shared backing buffer + byte range.
This is useful for container formats that can provide a view into a larger buffer (e.g. WebFile entries).