pub struct VersionCompatibility;Expand description
Unity version compatibility checker
Implementations
Sourceimpl VersionCompatibility
impl VersionCompatibility
Sourcepub fn is_supported(version: &UnityVersion) -> bool
pub fn is_supported(version: &UnityVersion) -> bool
Check if a version is supported by this parser
Sourcepub fn get_recommended_settings(version: &UnityVersion) -> VersionSettings
pub fn get_recommended_settings(version: &UnityVersion) -> VersionSettings
Get recommended settings for a Unity version
Sourcepub fn get_known_versions() -> Vec<UnityVersion>
pub fn get_known_versions() -> Vec<UnityVersion>
Get a list of known Unity versions for testing