Bundle resource loading and management
This module provides functionality for loading and managing resources from Unity AssetBundles.
Structs
- Bundle
Loader - Bundle resource loader
- Bundle
Resource Manager - Bundle resource manager
- Loader
Statistics - Loader statistics
Functions
- load_
bundle - Convenience functions for quick bundle loading Load a single bundle from file
- load_
bundle_ from_ memory - Load a bundle from memory
- load_
bundle_ with_ options - Load a bundle with specific options